@@ -72,8 +72,53 @@ class TestQp(BaseTest):
 
         # Check for all installed QP solvers
         self.solvers = [x for x in QP_SOLVERS if x in INSTALLED_SOLVERS]
-        if 'MOSEK' in INSTALLED_SOLVERS:
-            self.solvers.append('MOSEK')
+
+        def is_mosek_available():
+            """Check if MOSEK is installed and a license is available."""
+            if 'MOSEK' not in INSTALLED_SOLVERS:
+                return False
+            try:
+                import mosek  # type: ignore
+                env = mosek.Env()
+                # Try to get license status (returns 0 if OK)
+                status = env.getlicense()
+                return status == mosek.rescode.ok
+            except Exception:
+                return False
+
+        def is_knitro_available():
+            """Check if KNITRO is installed and a license is available."""
+            if 'KNITRO' not in INSTALLED_SOLVERS:
+                return False
+            try:
+                import knitro  # type: ignore
+                # Try to create and delete a Knitro solver instance
+                kc = knitro.KN_new()
+                if kc is None:
+                    return False
+                knitro.KN_free(kc)
+                return True
+            except Exception:
+                return False
+
+        def is_xpress_available():
+            """Check if XPRESS is installed and a license is available."""
+            if 'XPRESS' not in INSTALLED_SOLVERS:
+                return False
+            try:
+                import xpress  # type: ignore
+                env = xpress.env()
+                status = env.getlicense()
+                return status == 0
+            except Exception:
+                return False
+        # Remove XPRESS if license is not available
+        if 'XPRESS' in self.solvers and not is_xpress_available():
+            self.solvers.remove('XPRESS')
+        if 'MOSEK' in self.solvers and not is_mosek_available():
+            self.solvers.remove('MOSEK')
+        if 'KNITRO' in self.solvers and not is_knitro_available():
+            self.solvers.remove('KNITRO')
 
     def solve_QP(self, problem, solver_name):
         return problem.solve(solver=solver_name, verbose=False)
@@ -484,6 +529,33 @@ class TestQp(BaseTest):
                 assert X_vals[row, col] + 1 == model_x[i].start
                 assert np.isclose(X.value[row, col], model_x[i].x)
 
+    def test_xpress_warmstart(self) -> None:
+        """Test XPRESS warm start with a user provided point.
+        """
+        if cp.XPRESS in INSTALLED_SOLVERS:
+            m = 20
+            n = 10
+            np.random.seed(1)
+            A = np.random.randn(m, n)
+            b = Parameter(m)
+
+            # Construct the problem.
+            x = Variable(n, integer=True)
+            prob = Problem(Minimize(sum_squares(A @ x - b)))
+
+            b.value = np.random.randn(m)
+            result = prob.solve(solver=cp.XPRESS, warm_start=False)
+            result2 = prob.solve(solver=cp.XPRESS, warm_start=True)
+            self.assertAlmostEqual(result, result2)
+            x.value = x.value.astype(np.int64)
+
+            xprime = Variable(n, integer=True)
+            prob = Problem(Minimize(sum_squares(A @ xprime - b)))
+            xprime.value = x.value
+            result = prob.solve(solver=cp.XPRESS, warm_start=True)
+            result2 = prob.solve(solver=cp.XPRESS, warm_start=False)
+            self.assertAlmostEqual(result, result2)
+
     def test_highs_warmstart(self) -> None:
         """Test warm start.
         """
@@ -508,7 +580,7 @@ class TestQp(BaseTest):
             self.assertAlmostEqual(result, result2)
 
     def test_highs_cvar(self) -> None:
-        """Test problem with CVaR constraint from 
+        """Test problem with CVaR constraint from
         https://github.com/cvxpy/cvxpy/issues/2836
         """
         if cp.HIGHS in INSTALLED_SOLVERS:
